﻿//
//  Control External LED
//
//  This application uses the Netduino Plus to control the state of an external LED.
//
using System;
using System.Threading;
using Microsoft.SPOT.Hardware;
using SecretLabs.NETMF.Hardware.NetduinoPlus;

namespace Control_External_LED
{
    public class Program
    {
        /// <summary>
        /// Determine if the LED is on (true) or off (false)
        /// </summary>
        private static bool LEDState;

        /// <summary>
        /// Output port used to control the external LED circuit.
        /// </summary>
        private static OutputPort ExternalLED;

        /// <summary>
        /// Button on the Netduino PLus.
        /// </summary>
        private static InterruptPort OnBoardButton;
        
        /// <summary>
        /// Entry point for this application.
        /// </summary>
        public static void Main()
        {
            //
            //  Turn the LED off.
            //
            ExternalLED = new OutputPort(Pins.GPIO_PIN_D7, false);
            LEDState = false;
            ExternalLED.Write(LEDState);
            //
            //  Set up the button and listen for the user pressing the on board button.
            //
            OnBoardButton = new InterruptPort(Pins.ONBOARD_SW1, false, Port.ResistorMode.Disabled,
                                              Port.InterruptMode.InterruptEdgeLevelLow);
            OnBoardButton.OnInterrupt += new NativeEventHandler(button_OnInterrupt);

            Thread.Sleep(Timeout.Infinite);
        }

        /// <summary>
        /// Toggle the state of the pin controlling the external LED.
        /// </summary>
        private static void button_OnInterrupt(uint data1, uint data2, DateTime time)
        {
            LEDState = !LEDState;
            ExternalLED.Write(LEDState);
            if ((OnBoardButton.Interrupt == Port.InterruptMode.InterruptEdgeLevelLow) || (OnBoardButton.Interrupt == Port.InterruptMode.InterruptEdgeLevelHigh))
            {
                OnBoardButton.ClearInterrupt();
            }
        }
    }
}